
dialogId("kor-m-podivej", "font_small", "Look at all these lobsters...")

dialogId("kor-v-spitu", "font_big", "They sleep for thousands of years... in eternal stillness...")

dialogId("kor-m-avlada", "font_small", "...and the government tries to cover it up.")

dialogId("kor-v-nicje", "font_big", "...nothing can wake them up...")

dialogId("kor-m-pokud", "font_small", "Unless we activate that octopus.")

dialogId("kor-v-podivej", "font_big", "Look, everything here is so still and quiet.")

dialogId("kor-m-vzdyt", "font_small", "But the anemones are moving.")

dialogId("kor-v-treba", "font_big", "Maybe they’re in the throes of death.")

dialogId("kor-v-shledavam", "font_big", "I find a certain symbolism in that.")

dialogId("kor-v-bermudy", "font_big", "That’s interesting. This type of coral normally grows only in the Bermuda Triangle.")

dialogId("kor-v-inteligentni", "font_big", "Did you know that some types of coral are almost as intelligent as fish?")

dialogId("kor-v-jedovate", "font_big", "Be careful, most types of coral are poisonous.")

dialogId("kor-m-dusi", "font_small", "What do you think, is there such a thing as a ‘coral-soul’?")

dialogId("kor-m-pocit", "font_small", "Do you have the feeling that those coral are watching us?")

dialogId("kor-m-bizarni", "font_small", "I wonder why the coral have such a bizarre shape.")

dialogId("kor-v-juchacka", "font_big", "That was some number, wasn’t it?")

dialogId("kor-m-hraje", "font_small", "Yeah, he’s a great player.")

dialogId("kor-v-odvaz", "font_big", "That’s cool. What if we pushed him again?")

dialogId("kor-m-vsimlsis", "font_small", "Did you see what the lobsters were doing?")

dialogId("kor-v-avidelas", "font_big", "And how those anemones were dancing?")

dialogId("kor-m-tovis", "font_small", "Well, you know, it’s not all that much fun down here at the bottom of the ocean.")

dialogId("kor-v-vali", "font_big", "He’s good, isn’t he?")

dialogId("kor-m-nachob", "font_small", "Not bad for an octopus...")

dialogId("kor-m-jinou", "font_small", "Do you think he knows any other tune?")

dialogId("kor-m-neprehani", "font_small", "Don’t you think we’ve had enough already?")

dialogId("kor-m-lezekrkem", "font_small", "I’m getting sick of it...")

dialogId("kor-v-lezekrkem", "font_big", "I’m sick and tired of it...")

dialogId("kor-v-kostice", "font_big", "I’m fed up to the gills with this.")

dialogId("kor-v-odsud", "font_big", "I can’t budge this from where I am. I’d have to try to move it from the left side.")

dialogId("kor-m-budesmuset", "font_small", "Well you’ll have to go that way through those anemones.")

dialogId("kor-m-neniono", "font_small", "That’s not what I had in mind...")

dialogId("kor-m-tudiru", "font_small", "We should have plugged that hole beforehand.")

dialogId("kor-chob-chro", "", "")

dialogId("kor-chob-psi", "", "")

dialogId("kor-chob-tca", "", "")

dialogId("kor-room-music", "", "")
